#
# spec file for package gtkdatabox
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libver 1
Name:           gtkdatabox
Version:        1.0.0
Release:        bp156.2.5
Summary:        GTK+-3 widget for fast data display
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://sourceforge.net/projects/gtkdatabox
Source0:        %{URL}/files/gtkdatabox-1/%{name}-%{version}.tar.gz
BuildRequires:  gtk-doc >= 1.14
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gladeui-2.0) >= 3.4.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.4

%description
GtkDatabox is a widget for the Gtk+-3 library designed to display large
amounts of numerical data fast and easy.

%package devel
Summary:        Development files for GtkDatabox
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{libver} = %{version}
Suggests:       glade-catalog-%{name} = %{version}
# Conflict with GTK-2 version, which is named like this
Conflicts:      lib%{name}-devel

%description devel
The libgtkdatabox-devel package contains libraries, header files and
documentation for developing applications that use libgtkdatabox.

%package devel-examples
Summary:        Example code for using the library
Requires:       %{name}-devel = %{version}

%description devel-examples
GtkDatabox is a widget for the Gtk+-3 library designed to display large
amounts of numerical data fast and easy.
This package contains some example code for developing using GTKDataBox.

%package gtk-doc
Summary:        Documentation for GTKDataBox

%description gtk-doc
GtkDatabox is a widget for the Gtk+-3 library designed to display large
amounts of numerical data fast and easy.

%package -n glade-catalog-%{name}
Summary:        Glade catalog for GTKDataBox
Enhances:       glade >= 3.0

%description -n glade-catalog-%{name}
GtkDatabox is a widget for the Gtk+-3 library designed to display large
amounts of numerical data fast and easy.

%package -n lib%{name}%{libver}
Summary:        GTK+ widget for fast data display

%description -n lib%{name}%{libver}
GtkDatabox is a widget for the Gtk+-3 library designed to display large
amounts of numerical data fast and easy.

%prep
%setup -q

%build
autoreconf -fi
%configure \
  --disable-static \
  --enable-gtk-doc \
  --enable-glade
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n lib%{name}%{libver} -p /sbin/ldconfig
%postun -n lib%{name}%{libver} -p /sbin/ldconfig

%files -n lib%{name}%{libver}
%license COPYING
%{_libdir}/lib%{name}.so.*

%files devel
%doc AUTHORS ChangeLog NEWS README TODO
%doc examples/*.c
%{_includedir}/*
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/gtkdatabox.pc

%files devel-examples
%doc examples/*.c

%files gtk-doc
%doc %{_datadir}/gtk-doc/html/gtkdatabox-1

%files -n glade-catalog-%{name}
%{_datadir}/glade/catalogs/gtkdatabox.xml
%{_libdir}/glade/modules/libgladedatabox.so
%{_datadir}/icons/hicolor/scalable/apps/widget-gladedatabox-gtk_databox*.svg

%changelog
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.0.0
  * GTK+-3 is now required
  * Added: Convenience function to override the background-color
    of a databox gtk_databox_set_bg_color().
  * Using libtool's versioning system, to avoid breaking binary
    compatibility through every new minor-fixes release.
  * Deprecated function gdk_cairo_create
  * Deprecated functions to get/set background
  * Deprecated function gtk_adjustment_changed
    removed conditionally for GTK+ version >= 3.18.0
  * Deprecated function gdk_cursor_new
  * Deprecated function gtk_widget_override_background_color
  * Scrolling horizontally with Shift+ mouse middle button
  * Fixed:
  * Seg-fault using deprecated macro G_TYPE_INSTANCE_GET_PRIVATE.
  * Scrolling with mouse middle button or touch-pad.
  * Removed libglade support
- Split examples from devel package into devel-examples package
- Added glade-catalog and gtk-doc packages
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.9.3.1
  * bug fix that caused xoscope's background color to be
    displayed incorrectly
* Fri Dec 16 2016 Rene.vanPaassen@gmail.com
- update to version 0.9.3.0, mostly bugfixes and small addition;
  also the patches are no longer needed, removed.
- remove libgtkdatabox-0.9.1.3-gdk-deprecated.patch and
  libgtkdatabox-ld_fix.diff; fixed on upstream release
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 0.9.2.0
  * No short changelog available; please read the ChangeLog file
- Remove libgtkdatabox-0.9.1.3-gtk-2.22.patch; fixed on upstream
  release
- Update libgtkdatabox-ld_fix.diff
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Sep 22 2011 suse-tux@gmx.de
- added Patch2 (libgtkdatabox-ld_fix.diff) to fix the build for factory
  (link with -lm)
- added gtk-doc BuildRequire (needed for autoreconf call which is required
  by Patch2)
- moved %%%%configure into the %%%%build section
* Fri Sep  2 2011 kirill.kirillov@gmail.com
- cleaned spec using spec-cleaner
* Fri Aug 26 2011 kirill.kirillov@gmail.com
- initial package of version 0.9.1.3
